/*
	$Id: Informix.h,v 1.3 1995/05/25 21:18:56 timbo Rel $
*/

#include <DBIXS.h>		/* installed by the DBI module	*/

/* #define signed */

/* read in our implementation details */

#include "dbdimp.h"

/* end of Informix.h */
